appnope: Disable App Nap on macOS >= 10.9
=========================================

Description
-----------

Disable App Nap on macOS >= 10.9

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/appnope/

